zfit physics
------------

Tools and models to extend `zfit <https://github.com/zfit/zfit>`_.
The structure of this package is still in flow, so before opening any PR
you may want to open an issue to discuss how your proposed functionality will fit into `zfit-physics`.

It is currently under heavy development. Use it to test currently experimental
features. It offers a similar structure are zfit and will in the future be
simply integrated into the zfit namespace (given that zfit-physics is installed).

Installing
----------

zfit-physics is currently only available as a github version.
To install it, run this command in your terminal:

.. code-block:: console

   $ pip install git+https://github.com/zfit/zfit-physics

